##  Limitations
  * Deployment: On-premises Jira Service Management is not supported.
  * Authentication: OAuth authentication is not supported.
  * Fact sheet types: Only applications and IT components are available for synchronization.
  * Field types: User, Object, and Value fields are not supported.
  * Synchronization: Automated synchronization is not supported.
